==> igniteui-react-charts-18.1.0.tgz: package/esm5/lib/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RelativeStrengthIndexIndicator, _super);
    function RelativeStrengthIndexIndicator() {
        return _super.call(this) || this;
    }
    RelativeStrengthIndexIndicator.prototype.get_ts = function () {
        return 1;
    };
    RelativeStrengthIndexIndicator.prototype.get_ul = function () {
        return new RelativeStrengthIndexIndicatorStrategy();
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "ul", {
        get: function () {
            return this.get_ul();
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.get_uy = function () {
        return RelativeStrengthIndexIndicator.$;
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "uy", {
        get: function () {
            return this.get_uy();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "u6", {
        get: function () {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.u7));
        },
        set: function (a) {
            this.h(RelativeStrengthIndexIndicator.u7, a);
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.ur = function () {
        return this.u6;
    };
    RelativeStrengthIndexIndicator.prototype.u0 = function (a) {
        this.u6 = a;
    };
    RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.u7 = StrategyBasedIndicator.u3(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
}(StrategyBasedIndicator));
export { RelativeStrengthIndexIndicator };

==> igniteui-react-charts-18.2.0.tgz: package/esm5/lib/RelativeStrengthIndexIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RelativeStrengthIndexIndicatorStrategy } from "./RelativeStrengthIndexIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core";
/**
 * @hidden
 */
var RelativeStrengthIndexIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RelativeStrengthIndexIndicator, _super);
    function RelativeStrengthIndexIndicator() {
        return _super.call(this) || this;
    }
    RelativeStrengthIndexIndicator.prototype.get_tw = function () {
        return 1;
    };
    RelativeStrengthIndexIndicator.prototype.get_up = function () {
        return new RelativeStrengthIndexIndicatorStrategy();
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "up", {
        get: function () {
            return this.get_up();
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.get_u2 = function () {
        return RelativeStrengthIndexIndicator.$;
    };
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "u2", {
        get: function () {
            return this.get_u2();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(RelativeStrengthIndexIndicator.prototype, "va", {
        get: function () {
            return typeGetValue(this.c(RelativeStrengthIndexIndicator.vb));
        },
        set: function (a) {
            this.h(RelativeStrengthIndexIndicator.vb, a);
        },
        enumerable: false,
        configurable: true
    });
    RelativeStrengthIndexIndicator.prototype.uv = function () {
        return this.va;
    };
    RelativeStrengthIndexIndicator.prototype.u4 = function (a) {
        this.va = a;
    };
    RelativeStrengthIndexIndicator.$t = markType(RelativeStrengthIndexIndicator, 'RelativeStrengthIndexIndicator', StrategyBasedIndicator.$);
    RelativeStrengthIndexIndicator.vb = StrategyBasedIndicator.u7(14, RelativeStrengthIndexIndicator.$);
    return RelativeStrengthIndexIndicator;
}(StrategyBasedIndicator));
export { RelativeStrengthIndexIndicator };
